@@ -6,7 +6,11 @@
 #' @inheritParams simulatePedigree
 #' @inheritParams createGenDataFrame
 #' @return A data frame representing the simulated pedigree, including columns for family ID (`fam`),
-buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE) {
+buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE,
+                                   personID = "ID",
+                                   momID = "momID",
+                                   dadID = "dadID",
+                                   code_male = "M", code_female = "F") {
   for (i in 1:Ngen) {
     idGen <- as.numeric(paste(100, i, 1:sizeGens[i], sep = ""))
     # idGen <- ifelse(i==1,
@@ -22,7 +26,11 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE)
 
     ### Let's deal with the sex in each generation first
 
-    df_Ngen$sex <- determineSex(idGen = idGen, sexR = sexR)
+    df_Ngen$sex <- determineSex(
+      idGen = idGen, sexR = sexR,
+      code_male = code_male,
+      code_female = code_female
+    )
 
     # message(paste("tiger",i))
     # The first generation
@@ -30,8 +38,8 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE)
       df_Ngen$spID[1] <- df_Ngen$id[2]
       df_Ngen$spID[2] <- df_Ngen$id[1]
 
-      df_Ngen$sex[1] <- "F"
-      df_Ngen$sex[2] <- "M"
+      df_Ngen$sex[1] <- code_female
+      df_Ngen$sex[2] <- code_male
     }
 
     ## Connect male and female into couples in each generations
@@ -40,8 +48,8 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE)
     usedMaleIds <- numeric()
     # reserve the single persons
     if (i != 1 && i != Ngen) {
-      nMerriedFemale <- round(sum(df_Ngen$sex == "F") * marR_crt)
-      nMerriedMale <- round(sum(df_Ngen$sex == "M") * marR_crt)
+      nMerriedFemale <- round(sum(df_Ngen$sex == code_female) * marR_crt)
+      nMerriedMale <- round(sum(df_Ngen$sex == code_male) * marR_crt)
       # make sure there are same numbers of married males and females
       if (nMerriedFemale >= nMerriedMale) {
         nMerriedFemale <- nMerriedMale
@@ -49,14 +57,14 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE)
         nMerriedMale <- nMerriedFemale
       }
       # get the number of single males and females
-      nSingleFemale <- sum(df_Ngen$sex == "F") - nMerriedFemale
-      nSingleMale <- sum(df_Ngen$sex == "M") - nMerriedMale
+      nSingleFemale <- sum(df_Ngen$sex == code_female) - nMerriedFemale
+      nSingleMale <- sum(df_Ngen$sex == code_male) - nMerriedMale
 
 
       # sample single ids from male ids and female ids
-      usedFemaleIds <- sample(df_Ngen$id[df_Ngen$sex == "F"], nSingleFemale)
+      usedFemaleIds <- sample(df_Ngen$id[df_Ngen$sex == code_female], nSingleFemale)
       ## message(c("Used F", usedFemaleIds))
-      usedMaleIds <- sample(df_Ngen$id[df_Ngen$sex == "M"], nSingleMale)
+      usedMaleIds <- sample(df_Ngen$id[df_Ngen$sex == code_male], nSingleMale)
       ## message(c("Used M", usedMaleIds))
 
       usedIds <- c(usedFemaleIds, usedMaleIds)
@@ -67,10 +75,10 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE)
           next
         } else {
           # idx <- j+1
-          if (df_Ngen$sex[j] == "F") {
+          if (df_Ngen$sex[j] == code_female) {
             for (k in seq_len(nrow(df_Ngen))) {
               idr <- df_Ngen$id[k]
-              tgt <- (!(idr %in% usedIds)) & df_Ngen$sex[k] == "M"
+              tgt <- (!(idr %in% usedIds)) & df_Ngen$sex[k] == code_male
               # tgt <- ifelse(is.na(tgt),FALSE,TRUE)
               if (tgt) {
                 df_Ngen$spID[j] <- df_Ngen$id[k]
@@ -84,7 +92,7 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE)
           } else {
             for (k in seq_len(nrow(df_Ngen))) {
               idr <- df_Ngen$id[k]
-              tgt <- (!(idr %in% usedIds)) & df_Ngen$sex[k] == "F"
+              tgt <- (!(idr %in% usedIds)) & df_Ngen$sex[k] == code_female
               # tgt <- ifelse(is.na(tgt),FALSE,TRUE)
               if (tgt) {
                 df_Ngen$spID[j] <- df_Ngen$id[k]
@@ -134,7 +142,11 @@ buildWithinGenerations <- function(sizeGens, marR, sexR, Ngen, verbose = FALSE)
 #'         as well as assigning unique couple IDs. It does not return a value explicitly.
 #'
 
-buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, marR, sexR, kpc, rd_kpc) {
+buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, marR, sexR, kpc,
+                                    rd_kpc, personID = "ID",
+                                    momID = "momID",
+                                    dadID = "dadID",
+                                    code_male = "M", code_female = "F") {
   df_Fam$ifparent <- FALSE
   df_Fam$ifson <- FALSE
   df_Fam$ifdau <- FALSE
@@ -186,9 +198,9 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, mar
       # get the number of linked female and male children after excluding the single children
       # get a vector of single person id in the ith generation
       IdSingle <- df_Ngen$id[is.na(df_Ngen$spID)]
-      SingleF <- sum(df_Ngen$sex == "F" & is.na(df_Ngen$spID))
+      SingleF <- sum(df_Ngen$sex == code_female & is.na(df_Ngen$spID))
       CoupleF <- N_LinkedFemale - SingleF
-      SingleM <- sum(df_Ngen$sex == "M" & is.na(df_Ngen$spID))
+      SingleM <- sum(df_Ngen$sex == code_male & is.na(df_Ngen$spID))
       CoupleM <- N_LinkedMale - SingleM
 
       df_Fam[df_Fam$gen == i, ] <- markPotentialChildren(
@@ -196,7 +208,9 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, mar
         i = i,
         Ngen = Ngen,
         sizeGens = sizeGens,
-        CoupleF = CoupleF
+        CoupleF = CoupleF,
+        code_male = code_male,
+        code_female = code_female
       )
       if (verbose) {
         message(
@@ -250,7 +264,10 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, mar
         IdOfp <- evenInsert(IdSon, IdDau)
 
         # generate link kids to the couples
-        random_numbers <- adjustKidsPerCouple(nMates = sum(df_Ngen$ifparent) / 2, kpc = kpc, rd_kpc = rd_kpc)
+        random_numbers <- adjustKidsPerCouple(
+          nMates = sum(df_Ngen$ifparent) / 2, kpc = kpc,
+          rd_kpc = rd_kpc
+        )
 
         # cat("final random numbers",random_numbers, "\n")
         # cat("mean",sum(random_numbers)/length(random_numbers), "\n")
@@ -264,12 +281,12 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, mar
           # check if the id is used
           if (!df_Ngen$id[l] %in% usedIds) {
             # check if the member can be a parent
-            if (df_Ngen$ifparent[l] == TRUE && df_Ngen$sex[l] == "F") {
+            if (df_Ngen$ifparent[l] == TRUE && df_Ngen$sex[l] == code_female) {
               usedIds <- c(usedIds, df_Ngen$id[l], df_Ngen$spID[l])
               IdMa <- c(IdMa, rep(df_Ngen$id[l], random_numbers[idx]))
               IdPa <- c(IdPa, rep(df_Ngen$spID[l], random_numbers[idx]))
               idx <- idx + 1
-            } else if (df_Ngen$ifparent[l] == TRUE && df_Ngen$sex[l] == "M") {
+            } else if (df_Ngen$ifparent[l] == TRUE && df_Ngen$sex[l] == code_male) {
               usedIds <- c(usedIds, df_Ngen$id[l], df_Ngen$spID[l])
               IdPa <- c(IdPa, rep(df_Ngen$id[l], random_numbers[idx]))
               IdMa <- c(IdMa, rep(df_Ngen$spID[l], random_numbers[idx]))
@@ -343,8 +360,11 @@ buildBetweenGenerations <- function(df_Fam, Ngen, sizeGens, verbose = FALSE, mar
 #' @param balancedSex Not fully developed yet. Always \code{TRUE} in the current version.
 #' @param balancedMar Not fully developed yet. Always \code{TRUE} in the current version.
 #' @param verbose logical  If TRUE, message progress through stages of algorithm
+#' @param code_male The value to use for males. Default is "M"
+#' @param code_female The value to use for females. Default is "F"
 #' @param ... Additional arguments to be passed to other functions.
-
+#' @inheritParams ped2fam
+#' @param spouseID The name of the column that will contain the spouse ID in the output data frame. Default is "spID".
 #' @return A \code{data.frame} with each row representing a simulated individual. The columns are as follows:
 #' \itemize{
 #'   \item{fam: The family id of each simulated individual. It is 'fam1' in a single simulated pedigree.}
@@ -364,7 +384,13 @@ simulatePedigree <- function(kpc = 3,
                              rd_kpc = FALSE,
                              balancedSex = TRUE,
                              balancedMar = TRUE,
-                             verbose = FALSE) {
+                             verbose = FALSE,
+                             personID = "ID",
+                             momID = "momID",
+                             dadID = "dadID",
+                             spouseID = "spouseID",
+                             code_male = "M",
+                             code_female = "F") {
   # SexRatio: ratio of male over female in the offspring setting; used in the between generation combinations
   # SexRatio <- sexR / (1 - sexR)
 
@@ -381,7 +407,12 @@ simulatePedigree <- function(kpc = 3,
     Ngen = Ngen,
     sexR = sexR,
     marR = marR,
-    verbose = verbose
+    verbose = verbose,
+    personID = personID,
+    momID = momID,
+    dadID = dadID,
+    code_male = code_male,
+    code_female = code_female
   )
   if (verbose) {
     message(
@@ -397,16 +428,21 @@ simulatePedigree <- function(kpc = 3,
     marR = marR,
     sexR = sexR,
     kpc = kpc,
-    rd_kpc = rd_kpc
+    rd_kpc = rd_kpc,
+    personID = personID,
+    momID = momID,
+    dadID = dadID,
+    code_male = code_male,
+    code_female = code_female
   )
 
   df_Fam <- df_Fam[, 1:7]
   df_Fam <- df_Fam[!(is.na(df_Fam$pat) & is.na(df_Fam$mat) & is.na(df_Fam$spID)), ]
 
-  colnames(df_Fam)[c(2, 4, 5)] <- c("ID", "dadID", "momID")
+  colnames(df_Fam)[c(2, 4, 5)] <- c(personID, dadID, momID)
 
   # connect the detached members
-  df_Fam[is.na(df_Fam$momID) & is.na(df_Fam$dadID) & df_Fam$gen > 1, ]
+  df_Fam[is.na(df_Fam[[momID]]) & is.na(df_Fam[[dadID]]) & df_Fam$gen > 1, ]
   # if the sex rate is .5, make there is a 50% chance to change male to female and female to male
   # doesn't seem to produce the expected results, sometimes leads to moms being classified as dads
   #  if (sexR == .5 & runif(1) > .5) {
